This package extracts CBS Sports fantasy league data. It currently only works for March Madness pools. Planning to add other sports in the future. This package was heavily inspired by [cwendt94/espn-api](https://github.com/cwendt94/espn-api)

[Check out the Wiki](https://github.com/JohnDiebold/cbs-sports-api/wiki)


